pub struct Config {
pub current: String,
pub profiles: BTreeMap<String, Profile>,
}Fields
current: Stringprofiles: BTreeMap<String, Profile>Implementations
Sourceimpl Config
impl Config
pub fn default_path() -> PathBuf
Sourcepub fn load(path: &Path) -> Result<Config>
pub fn load(path: &Path) -> Result<Config>
Treat a missing file as an empty config so config init works on a new
machine.
Sourcepub fn permission_warning(path: &Path) -> Option<String>
pub fn permission_warning(path: &Path) -> Option<String>
Describe insecure file permissions, or return None for absent or
owner-only files.
The caller decides whether and how to display this warning, including
for CLI --json output.
pub fn save(&self, path: &Path) -> Result<()>