pub struct Error {
pub kind: ErrorKind,
pub http_status: Option<u16>,
pub message: String,
}Fields
kind: ErrorKindhttp_status: Option<u16>message: StringImplementations
Sourceimpl Error
impl Error
pub fn new(kind: ErrorKind, message: impl Into<String>) -> Self
pub fn with_status( kind: ErrorKind, status: u16, message: impl Into<String>, ) -> Self
Sourcepub fn from_response_body(status: u16, body: &str) -> Self
pub fn from_response_body(status: u16, body: &str) -> Self
Classify an HTTP error response.
Kibana returns {"statusCode":..,"error":..,"message":..}. The Elastic
Cloud edge proxy returns {"ok":false,"message":".."}. The latter also
appears when a project rename leaves a hostname unresolved.
Sourcepub fn to_envelope(&self) -> Value
pub fn to_envelope(&self) -> Value
Return the JSON object written to stderr when a command fails.